stopStream method
Stops the camera image stream. The scanner will stop processing frames and remain on the current preview frame.
Implementation
Future<void> stopStream() async {
_state?._stopCameraStream();
}
Stops the camera image stream. The scanner will stop processing frames and remain on the current preview frame.
Future<void> stopStream() async {
_state?._stopCameraStream();
}