QrLensScannerController class
Provides programmatic control over QrLensScannerPage.
Pass an instance to QrLensScannerPage.controller and call scanFromFile
to trigger a scan from any XFile — e.g. one returned by a custom image
picker, file_picker, or photo_manager.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resumeStream(
) → Future< void> - Resumes the camera image stream after it has been stopped manually or by disabling QrLensScannerPage.autoResume.
-
scanFromFile(
XFile file) → Future< void> -
Scan a QR code from
file. No-op if a scan is already in progress. -
stopStream(
) → Future< void> - Stops the camera image stream. The scanner will stop processing frames and remain on the current preview frame.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited