ScannerBox class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- ScannerBox
Constructors
- ScannerBox({Key? key, required Rect boundingRect, required double scanProgress, required double alpha, bool isScanned = false, bool isIdle = false, bool isCapturing = false, bool showQrContent = false, String? qrData, Rect? qrStartRect, Rect? qrTargetRect, double qrProgress = 0.0, Color accentColor = kAccent, Color successColor = kSuccess, Color scanLineColor = kAccent})
-
const
Properties
- accentColor → Color
-
final
- alpha → double
-
final
- boundingRect → Rect
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCapturing → bool
-
final
- isIdle → bool
-
final
- isScanned → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- qrData → String?
-
final
- qrProgress → double
-
final
- qrStartRect → Rect?
-
final
- qrTargetRect → Rect?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scanLineColor → Color
-
final
- scanProgress → double
-
final
- showQrContent → bool
-
final
- successColor → Color
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited