ViewfinderState class
State snapshot passed to QrLensScannerPage.viewFinderBuilder.
Constructors
Properties
- boundingRect → Rect
-
The computed viewfinder bounding rectangle.
final
- detectedRect → Rect?
-
The detected QR corner rect, or null.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCapturing → bool
-
Whether a QR is currently being captured.
final
- isShowingResult → bool
-
Whether the scanner is in the "showing result" phase.
final
- overlayAlpha → double
-
Current overlay alpha.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scannedValue → String?
-
The scanned value, or null.
final
- scanProgress → double
-
Normalised scan-line progress (0 → 1).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited